@@ -13,7 +13,7 @@ use Archive::Tar::Constant;
 
 use vars qw[@ISA $VERSION];
 #@ISA        = qw[Archive::Tar];
-$VERSION    = '1.74';
+$VERSION    = '1.80';
 
 ### set value to 1 to oct() it during the unpack ###
 my $tmpl = [
@@ -236,23 +236,23 @@ sub _new_from_chunk {
 
 sub _new_from_file {
     my $class       = shift;
-    my $path        = shift;        
-    
+    my $path        = shift;
+
     ### path has to at least exist
     return unless defined $path;
-    
+
     my $type        = __PACKAGE__->_filetype($path);
     my $data        = '';
 
-    READ: { 
+    READ: {
         unless ($type == DIR ) {
             my $fh = IO::File->new;
-        
+
             unless( $fh->open($path) ) {
                 ### dangling symlinks are fine, stop reading but continue
                 ### creating the object
                 last READ if $type == SYMLINK;
-                
+
                 ### otherwise, return from this function --
                 ### anything that's *not* a symlink should be
                 ### resolvable
@@ -405,7 +405,7 @@ sub _prefix_and_file {
 sub _filetype {
     my $self = shift;
     my $file = shift;
-    
+
     return unless defined $file;
 
     return SYMLINK  if (-l $file);	# Symlink
@@ -442,7 +442,7 @@ sub _downgrade_to_plainfile {
 
 =head2 $bool = $file->extract( [ $alternative_name ] )
 
-Extract this object, optionally to an alternative name. 
+Extract this object, optionally to an alternative name.
 
 See C<< Archive::Tar->extract_file >> for details.
 
@@ -452,9 +452,9 @@ Returns true on success and false on failure.
 
 sub extract {
     my $self = shift;
-    
+
     local $Carp::CarpLevel += 1;
-    
+
     return Archive::Tar->_extract_file( $self, @_ );
 }
 
@@ -576,7 +576,7 @@ Returns true on success and false on failure.
 sub rename {
     my $self = shift;
     my $path = shift;
-    
+
     return unless defined $path;
 
     my ($prefix,$file) = $self->_prefix_and_file( $path );
@@ -587,6 +587,48 @@ sub rename {
 	return 1;
 }
 
+=head2 $bool = $file->chmod $mode)
+
+Change mode of $file to $mode. The mode can be a string or a number
+which is interpreted as octal whether or not a leading 0 is given.
+
+Returns true on success and false on failure.
+
+=cut
+
+sub chmod {
+    my $self  = shift;
+    my $mode = shift; return unless defined $mode && $mode =~ /^[0-7]{1,4}$/;
+    $self->{mode} = oct($mode);
+    return 1;
+}
+
+=head2 $bool = $file->chown( $user [, $group])
+
+Change owner of $file to $user. If a $group is given that is changed
+as well. You can also pass a single parameter with a colon separating the
+use and group as in 'root:wheel'.
+
+Returns true on success and false on failure.
+
+=cut
+
+sub chown {
+    my $self = shift;
+    my $uname = shift;
+    return unless defined $uname;
+    my $gname;
+    if (-1 != index($uname, ':')) {
+	($uname, $gname) = split(/:/, $uname);
+    } else {
+	$gname = shift if @_ > 0;
+    }
+
+    $self->uname( $uname );
+    $self->gname( $gname ) if $gname;
+	return 1;
+}
+
 =head1 Convenience methods
 
 To quickly check the type of a C<Archive::Tar::File> object, you can
