@@ -11,7 +11,7 @@ use File::GlobMapper;
 require Exporter;
 our ($VERSION, @ISA, @EXPORT, %EXPORT_TAGS, $HAS_ENCODE);
 @ISA = qw(Exporter);
-$VERSION = '2.027';
+$VERSION = '2.037';
 
 @EXPORT = qw( isaFilehandle isaFilename whatIsInput whatIsOutput 
               isaFileGlobString cleanFileGlobString oneTarget
@@ -635,7 +635,7 @@ sub IO::Compress::Base::Parameters::parse
             ++ $parsed{$canonkey};
 
             return $self->setError("Muliple instances of '$key' found") 
-                if $parsed && $type & Parse_multiple == 0 ;
+                if $parsed && ($type & Parse_multiple) == 0 ;
 
             my $s ;
             $self->_checkType($key, $value, $type, 1, \$s)
@@ -901,9 +901,13 @@ sub add
         $self->[HIGH] += $value->[HIGH] ;
         $value = $value->[LOW];
     }
+    elsif ($value > MAX32) {      
+        $self->[HIGH] += int($value / HI_1) ;
+        $value = $value % HI_1;
+    }
      
     my $available = MAX32 - $self->[LOW] ;
-
+ 
     if ($value > $available) {
        ++ $self->[HIGH] ;
        $self->[LOW] = $value - $available - 1;
@@ -911,7 +915,33 @@ sub add
     else {
        $self->[LOW] += $value ;
     }
+}
 
+sub subtract
+{
+    my $self = shift;
+    my $value = shift;
+
+    if (ref $value eq 'U64') {
+
+        if ($value->[HIGH]) {
+            die "bad"
+                if $self->[HIGH] == 0 ||
+                   $value->[HIGH] > $self->[HIGH] ;
+
+           $self->[HIGH] -= $value->[HIGH] ;
+        }
+
+        $value = $value->[LOW] ;
+    }
+
+    if ($value > $self->[LOW]) {
+       -- $self->[HIGH] ;
+       $self->[LOW] = MAX32 - $self->[LOW] ;
+    }
+    else {
+       $self->[LOW] -= $value;
+    }
 }
 
 sub equal
@@ -929,6 +959,12 @@ sub is64bit
     return $self->[HIGH] > 0 ;
 }
 
+sub isAlmost64bit
+{
+    my $self = shift;
+    return $self->[HIGH] > 0 ||  $self->[LOW] == MAX32 ;
+}
+
 sub getPacked_V64
 {
     my $self = shift;
@@ -951,6 +987,21 @@ sub pack_V64
 }
 
 
+sub full32 
+{
+    return $_[0] == MAX32 ;
+}
+
+sub Value_VV64
+{
+    my $buffer = shift;
+
+    my ($lo, $hi) = unpack ("V V" , $buffer);
+    no warnings 'uninitialized';
+    return $hi * HI_1 + $lo;
+}
+
+
 package IO::Compress::Base::Common;
 
 1;
