@@ -33,8 +33,8 @@ apirevision=''
 apisubversion=''
 apiversion=''
 ar='arm-epoc-pe-ar'
-archlib='/usr/lib/perl/5.14.1/epoc'
-archlibexp='/usr/lib/perl/5.14.1/epoc'
+archlib='/usr/lib/perl/5.15.4/epoc'
+archlibexp='/usr/lib/perl/5.15.4/epoc'
 archname64=''
 archname='epoc'
 archobjs='epoc.o epocish.o epoc_stubs.o'
@@ -95,6 +95,7 @@ d_PRIi64='undef'
 d_PRIo64='undef'
 d_PRIu64='undef'
 d_PRIx64='undef'
+d_SCNfldbl='undef'
 d__fwalk='undef'
 d_access='undef'
 d_accessx='undef'
@@ -115,9 +116,11 @@ d_attribute_unused='undef'
 d_attribute_warn_unused_result='undef'
 d_bcmp='define'
 d_bcopy='define'
+d_bsd='undef'
 d_bsdgetpgrp='undef'
 d_bsdsetpgrp='undef'
-d_bsd='undef'
+d_builtin_choose_expr='undef'
+d_builtin_expect='undef'
 d_bzero='define'
 d_c99_variadic_macros='undef'
 d_casti32='undef'
@@ -130,13 +133,13 @@ d_class='undef'
 d_clearenv='define'
 d_closedir='undef'
 d_cmsghdr_s='undef'
-d_cmsghdr_s='undef'
 d_const='define'
 d_copysignl='undef'
 d_cplusplus='undef'
-d_crypt_r='undef'
 d_crypt='undef'
+d_crypt_r='undef'
 d_csh='undef'
+d_ctermid='undef'
 d_ctermid_r='undef'
 d_ctime64='undef'
 d_ctime_r='undef'
@@ -152,20 +155,20 @@ d_dlerror='undef'
 d_dlopen='undef'
 d_dlsymun='undef'
 d_dosuid='undef'
-d_drand48proto='define'
 d_drand48_r='undef'
+d_drand48proto='define'
 d_dup2='undef'
 d_eaccess='undef'
-d_endgrent_r='undef'
 d_endgrent='undef'
+d_endgrent_r='undef'
 d_endhent='undef'
 d_endhostent_r='undef'
 d_endnent='undef'
 d_endnetent_r='undef'
 d_endpent='undef'
 d_endprotoent_r='undef'
-d_endpwent_r='undef'
 d_endpwent='undef'
+d_endpwent_r='undef'
 d_endsent='undef'
 d_endservent_r='undef'
 d_eofnblk='define'
@@ -174,25 +177,26 @@ d_faststdio='undef'
 d_fchdir='undef'
 d_fchmod='undef'
 d_fchown='undef'
-d_fcntl_can_lock='undef'
 d_fcntl='undef'
+d_fcntl_can_lock='undef'
 d_fd_macros='undef'
-d_fds_bits='undef'
 d_fd_set='define'
+d_fds_bits='undef'
 d_fgetpos='define'
-d_finitel='undef'
 d_finite='undef'
+d_finitel='undef'
 d_flexfnam='define'
-d_flockproto='undef'
 d_flock='undef'
+d_flockproto='undef'
 d_fork='undef'
+d_fp_class='undef'
 d_fpathconf='undef'
+d_fpclass='undef'
 d_fpclassify='undef'
 d_fpclassl='undef'
-d_fp_class='undef'
-d_fpclass='undef'
 d_fpos64_t='undef'
 d_frexpl='undef'
+d_fs_data_s='undef'
 d_fseeko='undef'
 d_fsetpos='define'
 d_fstatfs='define'
@@ -204,10 +208,11 @@ d_futimes='undef'
 d_gdbm_ndbm_h_uses_prototypes='undef'
 d_gdbmndbm_h_uses_prototypes='undef'
 d_getaddrinfo='undef'
+d_getcwd='define'
 d_getespwnam='undef'
 d_getfsstat='undef'
-d_getgrent_r='undef'
 d_getgrent='undef'
+d_getgrent_r='undef'
 d_getgrgid_r='undef'
 d_getgrnam_r='undef'
 d_getgrps='undef'
@@ -220,8 +225,9 @@ d_gethostbyname_r='undef'
 d_gethostent_r='undef'
 d_gethostprotos='define'
 d_getitimer='undef'
-d_getlogin_r='undef'
 d_getlogin='undef'
+d_getlogin_r='undef'
+d_getmnt='undef'
 d_getmntent='undef'
 d_getnameinfo='undef'
 d_getnbyaddr='undef'
@@ -245,8 +251,8 @@ d_getprotobynumber_r='undef'
 d_getprotoent_r='undef'
 d_getprotoprotos='define'
 d_getprpwnam='undef'
-d_getpwent_r='undef'
 d_getpwent='undef'
+d_getpwent_r='undef'
 d_getpwnam_r='undef'
 d_getpwuid_r='undef'
 d_getsbyname='undef'
@@ -256,8 +262,8 @@ d_getservbyname_r='undef'
 d_getservbyport_r='undef'
 d_getservent_r='undef'
 d_getservprotos='define'
-d_getspnam_r='undef'
 d_getspnam='undef'
+d_getspnam_r='undef'
 d_gettimeod='define'
 d_gmtime64='undef'
 d_gmtime_r='undef'
@@ -266,6 +272,7 @@ d_grpasswd='undef'
 d_hasmntopt='undef'
 d_htonl='define'
 d_ilogbl='undef'
+d_inc_version_list='undef'
 d_index='undef'
 d_inetaton='define'
 d_inetntop='undef'
@@ -280,11 +287,12 @@ d_isnanl='undef'
 d_killpg='undef'
 d_lchown='undef'
 d_ldbl_dig='undef'
+d_libm_lib_version='0'
 d_link='undef'
 d_llseek='undef'
 d_localtime64='undef'
-d_localtime_r_needs_tzset='undef'
 d_localtime_r='undef'
+d_localtime_r_needs_tzset='undef'
 d_locconv='undef'
 d_lockf='undef'
 d_longdbl='undef'
@@ -303,32 +311,36 @@ d_memcpy='define'
 d_memmove='define'
 d_memset='define'
 d_mkdir='define'
+d_mkdtemp='undef'
 d_mkfifo='undef'
+d_mkstemp='undef'
+d_mkstemps='undef'
 d_mktime64='undef'
 d_mktime='define'
 d_mmap='undef'
+d_modfl='undef'
 d_modfl_pow32_bug='undef'
 d_modflproto='undef'
-d_modfl='undef'
 d_mprotect='undef'
-d_msgctl='undef'
+d_msg='undef'
 d_msg_ctrunc='undef'
 d_msg_dontroute='undef'
-d_msgget='undef'
-d_msghdr_s='undef'
-d_msghdr_s='undef'
 d_msg_oob='undef'
 d_msg_peek='undef'
 d_msg_proxy='undef'
+d_msgctl='undef'
+d_msgget='undef'
+d_msghdr_s='undef'
 d_msgrcv='undef'
 d_msgsnd='undef'
-d_msg='undef'
 d_msync='undef'
 d_munmap='undef'
 d_mymalloc='undef'
 d_ndbm_h_uses_prototypes='undef'
 d_nice='undef'
 d_nl_langinfo='undef'
+d_nv_preserves_uv='define'
+d_nv_zero_is_allbits_zero='undef'
 d_off64_t='undef'
 d_old_pthread_create_joinable='undef'
 d_oldpthreads='undef'
@@ -341,7 +353,11 @@ d_phostname='undef'
 d_pipe='undef'
 d_poll='undef'
 d_portable='undef'
+d_prctl='undef'
+d_prctl_set_name='undef'
+d_printf_format_null='undef'
 d_procselfexe='undef'
+d_pseudofork='undef'
 d_pthread_atfork='undef'
 d_pthread_attr_setscope='undef'
 d_pthread_yield='undef'
@@ -354,14 +370,13 @@ d_pwgecos='undef'
 d_pwpasswd='undef'
 d_pwquota='undef'
 d_qgcvt='undef'
+d_quad='define'
 d_random_r='undef'
 d_readdir64_r='undef'
 d_readdir='define'
 d_readdir_r='undef'
 d_readlink='undef'
 d_readv='undef'
-d_readv='undef'
-d_recvmsg='undef'
 d_recvmsg='undef'
 d_rename='define'
 d_rewinddir='define'
@@ -422,22 +437,29 @@ d_shmctl='undef'
 d_shmdt='undef'
 d_shmget='undef'
 d_sigaction='undef'
+d_signbit='undef'
 d_sigprocmask='undef'
 d_sigsetjmp='undef'
 d_sin6_scope_id='undef'
+d_sitearch='undef'
 d_snprintf='undef'
 d_sockaddr_sa_len='undef'
 d_sockatmark='undef'
 d_sockatmarkproto='undef'
 d_socket='define'
+d_socklen_t='undef'
 d_sockpair='undef'
 d_socks5_init='undef'
+d_sprintf_returns_strlen='undef'
+d_sqrtl='undef'
 d_srand48_r='undef'
 d_srandom_r='undef'
 d_sresgproto='undef'
 d_sresuproto='undef'
 d_statblks='define'
 d_statfs='undef'
+d_statfs_f_flags='undef'
+d_statfs_s='undef'
 d_statfsflags='define'
 d_static_inline='undef'
 d_statvfs='undef'
@@ -459,6 +481,8 @@ d_strlcat='undef'
 d_strlcpy='undef'
 d_strtod='define'
 d_strtol='define'
+d_strtold='undef'
+d_strtoll='undef'
 d_strtoq='undef'
 d_strtoul='define'
 d_strtoull='undef'
@@ -492,7 +516,10 @@ d_uname='undef'
 d_union_semun='undef'
 d_unordered='undef'
 d_unsetenv='undef'
+d_usleep='undef'
 d_usleepproto='undef'
+d_ustat='undef'
+d_vendorarch='undef'
 d_vendorlib='undef'
 d_vfork='undef'
 d_void_closedir='undef'
@@ -510,10 +537,14 @@ d_xenix='undef'
 date='date'
 db_hashtype='undef'
 db_prefixtype='undef'
+db_version_major='0'
+db_version_minor='0'
+db_version_patch='0'
 defvoidused='15'
 direntrytype='struct dirent'
 dlext='none'
 dlsrc='dl_none.xs'
+double='undef'
 doublesize='8'
 drand01='(rand()/(double)(1U<<RANDBITS))'
 drand48_r_proto='0'
@@ -565,6 +596,9 @@ getservbyname_r_proto='0'
 getservbyport_r_proto='0'
 getservent_r_proto='0'
 getspnam_r_proto='0'
+gidformat='"hu"'
+gidsign='1'
+gidsize='2'
 gidtype='gid_t'
 glibpth=''
 gmtime_r_proto='0'
@@ -576,6 +610,14 @@ h_fcntl=''
 h_sysfile=''
 hint=''
 hostcat=''
+i16size='2'
+i16type='short'
+i32size='4'
+i32type='int'
+i64size='8'
+i64type='long long'
+i8size='1'
+i8type='char'
 i_arpainet='define'
 i_assert='define'
 i_bsdioctl='undef'
@@ -620,6 +662,7 @@ i_sgtty='undef'
 i_shadow='undef'
 i_socks='undef'
 i_stdarg='define'
+i_stdbool='undef'
 i_stddef='define'
 i_stdlib='define'
 i_string='define'
@@ -630,7 +673,9 @@ i_sysfile='undef'
 i_sysfilio='undef'
 i_sysin='undef'
 i_sysioctl='define'
+i_syslog='undef'
 i_sysmman='undef'
+i_sysmode='undef'
 i_sysmount='undef'
 i_sysndir='undef'
 i_sysparam='define'
@@ -640,6 +685,7 @@ i_syssecrt='undef'
 i_sysselct='undef'
 i_syssockio='undef'
 i_sysstat='define'
+i_sysstatfs='undef'
 i_sysstatvfs='undef'
 i_systime='define'
 i_systimek='undef'
@@ -647,20 +693,43 @@ i_systimes='define'
 i_systypes='define'
 i_sysuio='undef'
 i_sysun='undef'
+i_sysutsname='undef'
+i_sysvfs='undef'
 i_syswait='define'
 i_termio='undef'
 i_termios='undef'
 i_time='define'
 i_unistd='define'
+i_ustat='undef'
 i_utime='undef'
 i_values='undef'
 i_varargs='undef'
 i_varhdr='undef'
 i_vfork='undef'
 ignore_versioned_solibs=''
+inc_version_list=' '
+inc_version_list_init='0'
 incpath=''
 inews=''
+installarchlib='/home/of/PERL/perl/lib/5.15.4/epoc'
+installbin='/home/of/PERL/System/Programs/'
+installman1dir='/home/of/PERL/man1'
+installman3dir='/home/of/PERL/man3'
+installprefix=''
+installprefixexp=''
+installprivlib='/home/of/PERL/perl/lib/5.15.4/'
+installscript='/home/of/PERL/bin/'
+installsitearch='/home/of/PERL/site/lib/site_perl/5.15.4/epoc'
+installsitelib='/home/of/PERL/perl/lib/site_perl/5.15.4'
+installstyle=''
+installusrbinperl='undef'
+installvendorarch=''
+installvendorlib=''
 intsize='4'
+issymlink=''
+ivdformat='"ld"'
+ivsize='4'
+ivtype='int'
 known_extensions='Data/Dumper File/Glob IO Socket Fcntl Sys/Hostname Errno'
 ksh=''
 ld='echo'
@@ -741,6 +810,13 @@ nm_opt=''
 nm_so_opt=''
 nonxs_ext='Errno'
 nroff='nroff'
+nv_overflows_integers_at='0'
+nv_preserves_uv_bits='32'
+nveformat='"e"'
+nvfformat='"f"'
+nvgformat='"g"'
+nvsize='16'
+nvtype='double'
 o_nonblock='O_NONBLOCK'
 obj_ext=''
 old_pthread_create_joinable=''
@@ -766,11 +842,13 @@ pmake=''
 pr=''
 prefix=''
 prefixexp=''
-privlib='/usr/lib/perl/5.14.1'
-privlibexp='/usr/lib/perl/5.14.1'
+privlib='/usr/lib/perl/5.15.4'
+privlibexp='/usr/lib/perl/5.15.4'
 procselfexe=''
 prototype='define'
 ptrsize='4'
+quadkind='QUAD_IS_LONG_LONG'
+quadtype='long long'
 randbits='31'
 randfunc=''
 random_r_proto='0'
@@ -779,6 +857,7 @@ ranlib='arm-epoc-pe-ranlib'
 rd_nodata='-1'
 readdir64_r_proto='0'
 readdir_r_proto='0'
+revision='5'
 rm='rm'
 rmail=''
 runnm='false'
@@ -798,6 +877,7 @@ sPRIi64=''
 sPRIo64=''
 sPRIu64=''
 sPRIx64=''
+sSCNfldbl=''
 sched_yield=''
 scriptdir=''
 scriptdirexp=''
@@ -826,11 +906,11 @@ sig_num='0'
 sig_num_init='0, 0'
 sig_size='1'
 signal_t='void'
-sitearch='/usr/lib/perl/site_perl/5.14.1/epoc'
-sitearchexp='/usr/lib/perl/site_perl/5.14.1/epoc'
-sitelib='/usr/lib/perl/site_perl/5.14.1/'
+sitearch='/usr/lib/perl/site_perl/5.15.4/epoc'
+sitearchexp='/usr/lib/perl/site_perl/5.15.4/epoc'
+sitelib='/usr/lib/perl/site_perl/5.15.4/'
 sitelib_stem='/usr/lib/perl/site_perl'
-sitelibexp='/usr/lib/perl/site_perl/5.14.1/'
+sitelibexp='/usr/lib/perl/site_perl/5.15.4/'
 siteprefix=''
 siteprefixexp=''
 sizesize='4'
@@ -840,7 +920,7 @@ smail=''
 so=''
 sockethdr=''
 socketlib=''
-socksizetype='size_t'
+socksizetype='int'
 sort='sort'
 spackage=''
 spitshell='cat'
@@ -848,6 +928,8 @@ srand48_r_proto='0'
 srandom_r_proto='0'
 src='.'
 ssizetype='long'
+st_ino_sign='1'
+st_ino_size='4'
 startperl=''
 startsh='#!/bin/sh'
 static_ext='Data/Dumper File/Glob IO Socket Fcntl Sys/Hostname'
@@ -865,6 +947,7 @@ subversion=''
 sysman=''
 tail=''
 tar=''
+targetarch=''
 tbl=''
 tee='tee'
 test='test'
@@ -876,10 +959,22 @@ tr='tr'
 trnl='\n'
 troff=''
 ttyname_r_proto='0'
+u16size='2'
+u16type='unsigned short'
+u32size='4'
+u32type='unsigned int'
+u64size='8'
+u64type='unsigned long long'
+u8size='1'
+u8type='unsigned char'
+uidformat='"hu"'
 uidsign='1'
+uidsize='2'
 uidtype='uid_t'
 uname='uname'
 uniq='uniq'
+uquadtype='uint64_t'
+use5005threads='undef'
 use64bitall='undef'
 use64bitint='undef'
 usecrosscompile='define'
@@ -887,6 +982,8 @@ usedevel='undef'
 usedl='undef'
 usedtrace='undef'
 usefaststdio='undef'
+useithreads='undef'
+usekernprocpathname='undef'
 uselargefiles='undef'
 uselongdouble='undef'
 usemallocwrap='undef'
@@ -894,6 +991,7 @@ usemorebits='undef'
 usemultiplicity='undef'
 usemymalloc='n'
 usenm=''
+usensgetexecutablepath='undef'
 useopcode=''
 useperlio='undef'
 useposix=''
@@ -908,13 +1006,21 @@ usevendorprefix=''
 usevfork=''
 usrinc=''
 uuname=''
+uvXUformat='"lX"'
+uvoformat='"lo"'
+uvsize='4'
+uvtype='unsigned int'
+uvuformat='"lu"'
+uvxformat='"lx"'
 vaproto='undef'
+vendorarch=''
+vendorarchexp=''
 vendorlib=''
 vendorlib_stem=''
 vendorlibexp=''
 vendorprefix=''
 vendorprefixexp=''
-version='5.14.1'
+version='5.15.4'
 versiononly='undef'
 vi=''
 voidflags='15'
@@ -937,273 +1043,13 @@ config_arg9=''
 config_arg10=''
 config_arg11=''
 PERL_REVISION=5
-PERL_VERSION=14
-PERL_SUBVERSION=1
+PERL_VERSION=15
+PERL_SUBVERSION=4
 PERL_API_REVISION=5
-PERL_API_VERSION=14
-PERL_API_SUBVERSION=0
+PERL_API_VERSION=15
+PERL_API_SUBVERSION=4
 PERL_CONFIG_SH=true
-# Variables propagated from previous config.sh file.
-pp_sys_cflags=''
-epocish_cflags='ccflags="$cflags -xc++"'
-ivtype='int'
-uvtype='unsigned int'
-i8type='char'
-u8type='unsigned char'
-i16type='short'
-u16type='unsigned short'
-i32type='int'
-u32type='unsigned int'
-i64type='long long'
-u64type='unsigned long long'
-d_quad='define'
-quadtype='long long'
-quadtype='unsigned long long'
-quadkind='QUAD_IS_LONG_LONG'
-nvtype='double'
-ivsize='4'
-uvsize='4'
-i8size='1'
-u8size='1'
-i16size='2'
-u16size='2'
-i32size='4'
-u32size='4'
-i64size='8'
-u64size='8'
-d_fs_data_s='undef'
-d_fseeko='undef'
-d_ldbl_dig='undef'
-d_sprintf_returns_strlen='undef'
-d_sqrtl='undef'
-d_getmnt='undef'
-d_statfs_f_flags='undef'
-d_statfs_s='undef'
-d_usleep='undef'
-d_ustat='undef'
-i_sysstatfs='undef'
-i_sysvfs='undef'
-i_ustat='undef'
-uidsize='2'
-uidsign='1'
-gidsize='2'
-gidsign='1'
-ivdformat='"ld"'
-uvuformat='"lu"'
-uvoformat='"lo"'
-uvxformat='"lx"'
-uvXUformat='"lX"'
-uidformat='"hu"'
-gidformat='"hu"'
-d_strtold='undef'
-d_strtoll='undef'
-d_strtouq='undef'
-d_nv_preserves_uv='define'
-nv_preserves_uv_bits='32'
-nv_overflows_integers_at='0'
-useithreads='undef'
-inc_version_list=' '
-inc_version_list_init='0'
-d_madvise='undef'
-d_mkdtemp='undef'
-d_mkstemp='undef'
-d_mkstemps='undef'
-d_mmap='undef'
-d_mprotect='undef'
-d_msync='undef'
-d_munmap='undef'
-d_qgcvt='undef'
-d_socklen_t='undef'
-d_vendorarch=''
-i_ieeefp='undef'
-i_sunmath='undef'
-i_syslog='undef'
-i_sysmman='undef'
-i_sysutsname='undef'
-installvendorarch=''
-mmaptype=''
-revision='5'
-sizesize='4'
-socksizetype='int'
-
-double='undef'
-usemorebits='undef'
-usemultiplicity='undef'
-usemymalloc='n'
-usenm=''
-useopcode=''
-useperlio='undef'
-useposix=''
-usesfio=''
-useshrplib=''
-usesocks='undef'
-usethreads='undef'
-usevendorprefix=''
-usevfork=''
-usrinc=''
-uuname=''
-vendorlib=''
-vendorlib_stem=''
-vendorlibexp=''
-vendorprefix=''
-vendorprefixexp=''
-version='5.14.1'
-vi=''
-voidflags='15'
-xlibpth=''
-zcat=''
-zip=''
-# Configure command line arguments.
-config_arg0=''
-config_args=''
-config_argc=11
-config_arg1=''
-config_arg2=''
-config_arg3=''
-config_arg4=''
-config_arg5=''
-config_arg6=''
-config_arg7=''
-config_arg8=''
-config_arg9=''
-config_arg10=''
-config_arg11=''
-PERL_REVISION=5
-PERL_VERSION=14
-PERL_SUBVERSION=1
-PERL_API_REVISION=5
-PERL_API_VERSION=14
-PERL_API_SUBVERSION=0
 CONFIGDOTSH=true
 # Variables propagated from previous config.sh file.
 pp_sys_cflags=''
 epocish_cflags='ccflags="$cflags -xc++"'
-ivtype='int'
-uvtype='unsigned int'
-i8type='char'
-u8type='unsigned char'
-i16type='short'
-u16type='unsigned short'
-i32type='int'
-u32type='unsigned int'
-i64type='long long'
-u64type='unsigned long long'
-d_quad='define'
-quadtype='long long'
-quadtype='unsigned long long'
-quadkind='QUAD_IS_LONG_LONG'
-nvtype='double'
-ivsize='4'
-uvsize='4'
-i8size='1'
-u8size='1'
-i16size='2'
-u16size='2'
-i32size='4'
-u32size='4'
-i64size='8'
-u64size='8'
-d_fs_data_s='undef'
-d_fseeko='undef'
-d_ldbl_dig='undef'
-d_sqrtl='undef'
-d_getmnt='undef'
-d_statfs_f_flags='undef'
-d_statfs_s='undef'
-d_ustat='undef'
-i_sysstatfs='undef'
-i_sysvfs='undef'
-i_ustat='undef'
-uidsize='2'
-uidsign='1'
-gidsize='2'
-gidsign='1'
-ivdformat='"ld"'
-uvuformat='"lu"'
-uvoformat='"lo"'
-uvxformat='"lx"'
-uidformat='"hu"'
-gidformat='"hu"'
-d_strtold='undef'
-d_strtoll='undef'
-d_strtouq='undef'
-d_nv_preserves_uv='define'
-d_nv_zero_is_allbits_zero='undef'
-use5005threads='undef'
-useithreads='undef'
-inc_version_list=' '
-inc_version_list_init='0'
-d_madvise='undef'
-d_mkdtemp='undef'
-d_mkstemp='undef'
-d_mkstemps='undef'
-d_mmap='undef'
-d_mprotect='undef'
-d_msync='undef'
-d_munmap='undef'
-d_qgcvt='undef'
-d_socklen_t='undef'
-d_vendorarch=''
-i_ieeefp='undef'
-i_sunmath='undef'
-i_syslog='undef'
-i_sysmman='undef'
-i_sysutsname='undef'
-installvendorarch=''
-mmaptype=''
-revision='5'
-sizesize='4'
-socksizetype='int'
-d_getcwd='define'
-i_sysmode='undef'
-d_vendorarch='undef'
-d_frexpl='undef'
-d_getespwnam='undef'
-d_getprpwnam='undef'
-d_isnan='define'
-d_isnanl='undef'
-d_modfl='undef'
-d_setproctitle='undef'
-d_socks5_init='undef'
-i_libutil='undef'
-i_prot='undef'
-d_SCNfldbl='undef'
-d_perl_otherlibdirs='undef'
-nvsize='16'
-issymlink=''
-installarchlib='/home/of/PERL/perl/lib/5.14.1/epoc'
-installbin='/home/of/PERL/System/Programs/'
-installman1dir='/home/of/PERL/man1'
-installman3dir='/home/of/PERL/man3'
-installprefix=''
-installprefixexp=''
-installprivlib='/home/of/PERL/perl/lib/5.14.1/'
-installscript='/home/of/PERL/bin/'
-installsitearch='/home/of/PERL/site/lib/site_perl/5.14.1/epoc'
-installsitelib='/home/of/PERL/perl/lib/site_perl/5.14.1'
-installstyle=''
-installusrbinperl='undef'
-installvendorlib=''
-nveformat='"e"'
-nvfformat='"f"'
-nvgformat='"g"'
-sSCNfldbl=''
-uquadtype='uint64_t'
-d_builtin_choose_expr='undef'
-d_builtin_expect='undef'
-d_ctermid='undef'
-d_inc_version_list='undef'
-d_libm_lib_version='0'
-d_prctl='undef'
-d_prctl_set_name='undef'
-d_printf_format_null='undef'
-d_pseudofork='undef'
-d_signbit='undef'
-d_sitearch='undef'
-db_version_major='0'
-db_version_minor='0'
-db_version_patch='0'
-targetarch=''
-vendorarch=''
-vendorarchexp=''
-
